LPARAMETERS tcFRXFullFileName, tnOutPutFileType, tnScope, tnRecord, tcForExpr, tcWhileExpr, tcHeading, tlPlain, tlSummary

*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/downloads/release.asp?releaseid=32738
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


*-- DO SAMPLE WITH 'C:\MyReports\Customer list.FRX', 2

*-- tcFRXFullFileName	: FRX File Path + FileName
*-- tnOutPutFileType	: cnWORD, cnHTML, cnRTF, cnEXCEL, cnXML, cnPREVIEW, cnPDF, cnIMAGE
*-- tnScope				: All  	 - cnSCOPE_CLAUSE_ALL
*-- 					: Next 	 - cnSCOPE_CLAUSE_NEXT
*-- 					: Record - cnSCOPE_CLAUSE_RECORD
*-- 					: Rest	 - cnSCOPE_CLAUSE_REST
*-- tnRecord			: Depending on tnScope will represent NEXT n records or RECORD n
*-- tcForExpr			: FOR condition (Expression)
*-- tcWhileExpr			: WHILE condition (Expression)
*-- tlPlain				: Plain report
*-- tlSummary			: Summary band only

***************************************************************************************************************************
*-- Export file types
***************************************************************************************************************************
#DEFINE cnWORD 					         		1
#DEFINE cnHTML               			 		2
#DEFINE cnRTF               			 		3
#DEFINE cnEXCEL               			 		4
#DEFINE cnXML               			 		5
#DEFINE cnPREVIEW               			 	6
#DEFINE cnPDF	               			 	    7
#DEFINE cnIMAGE	               			 	    8

***************************************************************************************************************************
*-- Return values 
***************************************************************************************************************************
#DEFINE cnOK 	     				     		0       && Everything is OK.
#DEFINE cnNO_PARAMETERS    				 		1       && No parameter
#DEFINE cnREP_FILE_NOT_FOUND			 		2       && Report file not found
#DEFINE cnNO_BANDS_DEFINED 				 		3       && No bands defined in FRX file (corrupted?)
#DEFINE cnNO_OPEN_TABLE    				 		4       && No open table and no dataenviroment cursors in FRX file
#DEFINE cnEOF           				 		5       && Main alias at EOF() and no dataenvironment cursors
#DEFINE cnCANNOT_INSTANCE_WORD_APP		 		6       && Cannot instance a Word.Application
#DEFINE cnNO_HEADER_RECORD 				 		7       && No header record in FRX file (corrupted?)
#DEFINE cnNO_ANY_OBJECTS   				 		8       && No labels, fields, or images.
#DEFINE cnERR_CREATING_FILE				 		9  	 	&& Error creating DOC
#DEFINE cnUSER_INTERRUPTED				 		10  	&& User interrupted

#DEFINE cnINVALID_BANDTYPE_PARAMETER	 		11  	 
#DEFINE cnINVALID_ARRAY_REPORT_OBJ_PARAMETER	12
#DEFINE cnINVALID_NUMBER_OF_PARAMETER			13
#DEFINE cnINVALID_TYPE_OF_PARAMETER	 			14  	 
#DEFINE cnINVALID_SPECIFIED_OBJECT_TYPE			15
#DEFINE cnWRONG_EXPORT_FILE_TYPE				16
#DEFINE cnDE_INIT_RETURN_FALSE					17		&& DE Init metod return false 
#DEFINE cnCANNOT_INSTANCE_EXCEL_APP		 		18      && Cannot instance a Excel.Application
#DEFINE cnCANNOT_INSTANCE_PREVIEW_FORM          19      && Cannot instance a Preview Form
#DEFINE cnCANNOT_INSTANCE_OUTLOOK_APP		 	20      && Cannot instance a Outlook.OutPut
#DEFINE cnCANNOT_INSTANCE_HTML_FILE				21
#DEFINE cnPAGEHEADER_BAND_IS_TOO_LARGE		 	22      && Page Header band is too large to fit on page
#DEFINE cnTITLE_BAND_IS_TOO_LARGE		 	    23      && Title band is too large to fit on page

#DEFINE cnCANNOT_INSTANCE_IMAGE_FILE			24
#DEFINE cnCANNOT_CREATE_COMPATIBLE_BITMAP		25
#DEFINE cnCOMPATIBLE_BITMAP_SELECTION_FAILED	26
#DEFINE cnFORM_TO_COMPATIBLE_BIT_FAILED			27
#DEFINE cnWRONG_DEVICE_CONTEXT					28
#DEFINE cnBITMAP_FAILED							29
#DEFINE cnCANNOT_FIND_WINDOW					30
#DEFINE cnOUT_OF_PAGES_RANGE					31
#DEFINE cnTHERE_IS_NO_PAGES_TO_PRINT			32
#DEFINE cnCANNOT_CREATE_IMAGE_FILE				33

#DEFINE cnCANNOT_INSTANCE_PDF_FILE				34
#DEFINE cnCANNOT_INSTANCE_XML_FILES				35
#DEFINE cnCANNOT_INSTANCE_GRAPHICS_OBJECT		36

***************************************************************************************************************************
*-- The scope clauses types 
***************************************************************************************************************************
#DEFINE cnSCOPE_CLAUSE_ALL		         		1
#DEFINE cnSCOPE_CLAUSE_NEXT		         		2
#DEFINE cnSCOPE_CLAUSE_RECORD	         		3
#DEFINE cnSCOPE_CLAUSE_REST 	         		4

***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         		1
#DEFINE cnOUTPUT_PRINT			         		2
#DEFINE cnOUTPUT_EMAIL			         		3
#DEFINE cnOUTPUT_FILE		 	         		4


LOCAL loFile

LOCAL lcDefaultPath
LOCAL lcReportFullName
LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath
LOCAL lcErrorMessage

LOCAL lcClassName
LOCAL lcModule
LOCAL lcInApplication

IF EMPTY(tcFRXFullFileName) OR !VARTYPE(tcFRXFullFileName) $ 'C'
   lcErrorMessage = 'FRX file name is required.'
   =MESSAGEBOX(lcErrorMessage, 16, 'Error')
        
	RETURN
ENDIF

IF !(VARTYPE(tnOutPutFileType) $ 'NFIBY' AND INLIST(tnOutPutFileType, cnWORD, cnHTML, cnRTF, cnEXCEL, cnXML, cnPREVIEW, cnPDF, cnIMAGE))
    tnOutPutFileType = cnPREVIEW
ENDIF

IF !(VARTYPE(tnScope) $ 'NFIBY' AND INLIST(tnScope, cnSCOPE_CLAUSE_ALL, cnSCOPE_CLAUSE_NEXT, cnSCOPE_CLAUSE_RECORD, cnSCOPE_CLAUSE_REST))
    tnScope = cnSCOPE_CLAUSE_ALL
ENDIF

tnRecord		 = IIF(INLIST(tnScope, cnSCOPE_CLAUSE_NEXT, cnSCOPE_CLAUSE_RECORD) AND EMPTY(tnRecord), 1, tnRecord)
tcForExpr		 = IIF(EMPTY(tcForExpr), '', tcForExpr)
tcWhileExpr		 = IIF(EMPTY(tcWhileExpr), '', tcWhileExpr)
tcHeading		 = IIF(EMPTY(tcHeading), '', tcHeading)
tlPlain			 = IIF(VARTYPE(tlPlain) = 'L', tlPlain, .F.)
tlSummary		 = IIF(VARTYPE(tlSummary) = 'L', tlSummary, .F.)

lcReportFullName = ALLTRIM(tcFRXFullFileName)
lcReportFullName = FORCEEXT(lcReportFullName, 'FRX')

lcOutPutFileName = JUSTSTEM(lcReportFullName)
lcOutPutFilePath = JUSTPATH(SYS(16,0)) + "\OutPut\"

IF !FILE(lcReportFullName)
    lcErrorMessage = 'File ' + lcReportFullName + ' does not exist.'
    =MESSAGEBOX(lcErrorMessage, 16, 'Error')

ELSE
    CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

    SET PATH TO  ..\..\
    SET CLASSLIB TO FRX2Any IN FRX2Any.APP ALIAS FRX2Any

    DO CASE
        CASE tnOutPutFileType = cnWORD
            loFile = CREATEOBJECT('FRX2Any.WordFile')

        CASE tnOutPutFileType = cnRTF
            loFile = CREATEOBJECT('FRX2Any.RTFFile')

        CASE tnOutPutFileType = cnHTML
            loFile = CREATEOBJECT('FRX2Any.HTMLFile')

        CASE tnOutPutFileType = cnEXCEL
            loFile = CREATEOBJECT('FRX2Any.EXCELFile')

        CASE tnOutPutFileType = cnPREVIEW
            loFile = CREATEOBJECT('FRX2Any.PREVIEWFile')

        CASE tnOutPutFileType = cnPDF
            loFile = CREATEOBJECT('FRX2Any.PDFFile')

        CASE tnOutPutFileType = cnXML
            loFile = CREATEOBJECT('FRX2Any.XMLFile')

        CASE tnOutPutFileType = cnIMAGE
            loFile = CREATEOBJECT('FRX2Any.IMAGEFile')

    ENDCASE

    IF TYPE('loFile') = 'O'

*-- Unlock FRX2Any
        loFile.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = "ReportOutput"
        loFile.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = "c:\MyApp\MyOutPut\"
        loFile.cSaveFolder     = lcOutPutFilePath

*-- Here we can get current version of FRX2Any
        lcVersion = loFile.GetVersion()

*-- Set up Report Scope
        loFile.nScopeClauseType = tnScope

        DO CASE
            CASE loFile.nScopeClauseType = cnSCOPE_CLAUSE_NEXT
                loFile.nScopeRecords = tnRecord

            CASE loFile.nScopeClauseType = cnSCOPE_CLAUSE_RECORD
                loFile.nScopeRecordNumber = tnRecord

        ENDCASE

        IF !EMPTY(tcForExpr)
            loFile.cFORExpression = ALLTRIM(tcForExpr)
        ENDIF

        IF !EMPTY(tcWhileExpr)
            loFile.cWHILEExpression = ALLTRIM(tcWhileExpr)
        ENDIF

        IF !EMPTY(tcHeading)
            loFile.cHeadingText = ALLTRIM(tcHeading)
        ENDIF

        loFile.lPlain   = tlPlain
        loFile.lSummary = tlSummary

*-- Force FRX2Any to display conversion process status
        loFile.lDisplayStatus  = .T.

*-- Specifies that output file will be displayed after creation
        loFile.nOutPutType = cnOUTPUT_SCREEN

        lnSuccess = loFile.SAVE(lcReportFullName)

        loFile.RELEASE()

    ELSE
        lcErrorMessage = 'Could not instatiate Frx2Any object.'
        =MESSAGEBOX(lcErrorMessage, 16, 'Error')

    ENDIF
ENDIF










